Jirachi
=================================
.. image:: https://github.com/RyanKung/jirachi/raw/master/icon.png
   :height: 100px
   :width: 200px
   :scale: 100 %
   :align: center

`jirachi` is an IO framework based on actor model

* Installation::

    pip install jirachi

* For postgresDB Monitor::

    pip install asyncpg

* For mongoDB Monitor::

    pip install motor
